@@ -1,9 +1,7 @@
 use lru::LruCache;
-use rio_backend::sugarloaf::font::ops::FontOps;
 use rio_backend::sugarloaf::font_introspector::Attributes;
 use std::collections::HashMap;
 use std::num::NonZeroUsize;
-use std::sync::Arc;
 use tracing::debug;
 use unicode_width::UnicodeWidthChar;
 
@@ -74,29 +72,12 @@ impl FontCache {
     }
 
     /// Clear all cache entries with cleanup
-    pub fn clear(&mut self, font_ops: &FontOps) {
-        // Perform cleanup for any expensive operations
-        font_ops.cleanup_cache();
-
+    #[allow(dead_code)]
+    pub fn clear(&mut self) {
         self.hot_cache.clear();
         self.cache.clear();
     }
 
-    /// Clear cache entries and cleanup font data
-    #[allow(dead_code)]
-    pub fn clear_with_font_data(
-        &mut self,
-        font_ops: &FontOps,
-        font_data: Vec<Arc<Vec<u8>>>,
-    ) {
-        // Release font data synchronously (it's fast enough)
-        if !font_data.is_empty() {
-            font_ops.release_font_data(font_data);
-        }
-
-        self.clear(font_ops);
-    }
-
     /// Pre-populate cache with common characters to improve hit rate
     /// This should be called during initialization with the font context
     pub fn pre_populate(
@@ -207,24 +188,4 @@ mod tests {
         // Cache should have all entries since we're under the limit
         assert_eq!(cache.len(), test_size + 1);
     }
-
-    #[test]
-    fn test_font_cache_clear() {
-        let mut cache = FontCache::new();
-        let font_ops = FontOps::new();
-
-        // Add some entries
-        for i in 0..10 {
-            let attrs = Attributes::new(Stretch::NORMAL, Weight::NORMAL, Style::Normal);
-            let key = (char::from_u32(i as u32 + 65).unwrap_or('A'), attrs);
-            let value = (i, i as f32);
-            cache.insert(key, value);
-        }
-
-        assert_eq!(cache.len(), 10);
-
-        cache.clear(&font_ops);
-        assert!(cache.is_empty());
-        assert_eq!(cache.len(), 0);
-    }
 }
