@@ -135,8 +135,14 @@ pub struct SugarloafFonts {
     pub emoji: Option<SugarloafFont>,
     #[serde(default = "Vec::default")]
     pub extras: Vec<SugarloafFont>,
+    #[serde(default = "default_bool_true", rename = "use-drawable-chars")]
+    pub use_drawable_chars: bool,
     #[serde(default = "Option::default", rename = "symbol-map")]
     pub symbol_map: Option<Vec<SymbolMap>>,
+    #[serde(default = "bool::default", rename = "disable-warnings-not-found")]
+    pub disable_warnings_not_found: bool,
+    #[serde(default = "Option::default", rename = "additional-dirs")]
+    pub additional_dirs: Option<Vec<String>>,
 }
 
 pub fn parse_unicode(input: &str) -> Option<char> {
@@ -162,7 +168,10 @@ impl Default for SugarloafFonts {
             bold_italic: default_font_bold_italic(),
             italic: default_font_italic(),
             extras: vec![],
+            use_drawable_chars: true,
             symbol_map: None,
+            disable_warnings_not_found: false,
+            additional_dirs: None,
         }
     }
 }
