@@ -16,12 +16,11 @@ pub use crate::sugarloaf::{
         ResizeParameter, MAX_GRAPHIC_DIMENSIONS,
     },
     primitives::*,
-    Sugarloaf, SugarloafErrors, SugarloafRenderer, SugarloafWindow, SugarloafWindowSize,
-    SugarloafWithErrors,
+    Colorspace, Sugarloaf, SugarloafErrors, SugarloafRenderer, SugarloafWindow,
+    SugarloafWindowSize, SugarloafWithErrors,
 };
 pub use components::filters::Filter;
-pub use components::quad::{ComposedQuad, Quad};
-pub use components::rect::Rect;
+pub use components::quad::Quad;
 pub use layout::{
     Content, FragmentStyle, FragmentStyleDecoration, SugarDimensions, UnderlineInfo,
     UnderlineShape,
